==> vue-ui-components-0.1.34.tgz: package/src/store/securetoken.ts <==
import { VuexModule, Module, Mutation, Action } from 'vuex-module-decorators';
import {
    WebPartContext
} from '@microsoft/sp-webpart-base';

@Module({ namespaced: true })
class SecureToken extends VuexModule {

    private spContext: any = {};
    private _apiBaseUrl: string = '';
    private _environment: string = 'unset';
    private _token: string = '';
    private _serverError: boolean = false;
    private _unauthorized: boolean = false;
    private _waitingOnServer: boolean = true;

    get sharepointContext() {
        return this.spContext;
    }

    get apiBaseUrl() {
        return this._apiBaseUrl;
    }

    get environment() {
        return this._environment;
    }

    get token() {
        return this._token;
    }

    get serverError() {
        return this._serverError;
    }

    get unauthorized() {
        return this._unauthorized;
    }

    get waitingOnServer() {
        return this._waitingOnServer;
    }

    @Mutation
    SET_WAITING_ON_SERVER(trueOrFalse: boolean) {
        this._waitingOnServer = trueOrFalse;
    }
 
    @Mutation
    public SET_SERVER_ERROR() {
        this._serverError = true;
        this._waitingOnServer = false;
    }

    @Mutation
    public SET_UNAUTHORIZED() {
        this._unauthorized = true;
        this._waitingOnServer = false;
    }

    @Mutation
    public SET_TOKEN(token: string) {
        this._token = token;
        localStorage.setItem('mgcToken', token);
    }

    @Mutation
    public SET_SPCONTEXT(spContext: WebPartContext) {
        this.spContext = spContext;
    }

    @Mutation
    public SET_API_BASE_URL(appBasePath: string) {
        const webPartUrl = this.spContext.manifest.loaderConfig.internalModuleBaseUrls;
        const envLocal = webPartUrl.some((u: string) => u.includes('localhost'));
        if (envLocal === true) {
            this._environment = 'local';
            this._apiBaseUrl = `http://localhost:7071/api/${appBasePath}`;
        }
        if (envLocal === false) {
            this._environment = 'production';
            this._apiBaseUrl = `https://mgcforms.azurewebsites.net/api/${appBasePath}`;
        }
    }

    @Action
    public setWaitingOnServer(trueOrFalse: boolean) {
        this.context.commit('SET_WAITING_ON_SERVER', trueOrFalse);
    }

    @Action
    public setServerError() {
        console.log('Setting server error from Vue Secure Token plugin');
        this.context.commit('SET_SERVER_ERROR');
    }

    @Action
    public setUnauthorized() {
        console.log('Setting unauthorized from Vue Secure Token plugin');
        this.context.commit('SET_UNAUTHORIZED');
    }

    @Action
    public setApi(args: { spContext: WebPartContext, appBasePath: string }) {
        this.context.commit('SET_SPCONTEXT', args.spContext);
        this.context.commit('SET_API_BASE_URL', args.appBasePath);
        this.context.dispatch('fetchJwtToken');
    }

    @Action({ rawError: true })
    public async fetchJwtToken() {
        try {
            const tokenProvider = await this.sharepointContext.aadTokenProviderFactory.getTokenProvider();
            const token = await tokenProvider.getToken("https://mccowngordon.sharepoint.com");
            this.context.commit('SET_TOKEN', token);
            return;
        }
        catch (err) {
            return Promise.reject(err);
        }
    }

}
export default SecureToken;

==> vue-ui-components-0.1.72.tgz: package/src/store/securetoken.ts <==
import { VuexModule, Module, Mutation, Action } from 'vuex-module-decorators';
import {
    WebPartContext
} from '@microsoft/sp-webpart-base';

@Module({ namespaced: true })
class SecureToken extends VuexModule {

    private spContext: any = {};
    private _apiBaseUrl: string = '';
    private _environment: string = 'unset';
    private _token: string = '';
    private _serverError: boolean = false;
    private _unauthorized: boolean = false;
    private _waitingOnServer: boolean = true;

    get sharepointContext() {
        return this.spContext;
    }

    get apiBaseUrl() {
        return this._apiBaseUrl;
    }

    get environment() {
        return this._environment;
    }

    get token() {
        return this._token;
    }

    get serverError() {
        return this._serverError;
    }

    get unauthorized() {
        return this._unauthorized;
    }

    get waitingOnServer() {
        return this._waitingOnServer;
    }

    @Mutation
    SET_WAITING_ON_SERVER(trueOrFalse: boolean) {
        this._waitingOnServer = trueOrFalse;
    }
 
    @Mutation
    public SET_SERVER_ERROR() {
        this._serverError = true;
        this._waitingOnServer = false;
    }

    @Mutation
    public SET_UNAUTHORIZED() {
        this._unauthorized = true;
        this._waitingOnServer = false;
    }

    @Mutation
    public SET_TOKEN(token: string) {
        this._token = token;
        localStorage.setItem('mgcToken', token);
    }

    @Mutation
    public SET_SPCONTEXT(spContext: WebPartContext) {
        this.spContext = spContext;
    }

    @Mutation
    public SET_API_BASE_URL(appBasePath: string) {
        const webPartUrl = this.spContext.manifest.loaderConfig.internalModuleBaseUrls;
        const envLocal = webPartUrl.some((u: string) => u.includes('localhost'));
        if (envLocal === true) {
            this._environment = 'local';
            this._apiBaseUrl = `http://localhost:7071/api/${appBasePath}`;
        }
        if (envLocal === false) {
            this._environment = 'production';
            this._apiBaseUrl = `https://mgcforms.azurewebsites.net/api/${appBasePath}`;
        }
    }

    @Action
    public setWaitingOnServer(trueOrFalse: boolean) {
        this.context.commit('SET_WAITING_ON_SERVER', trueOrFalse);
    }

    @Action
    public setServerError() {
        console.log('Setting server error from Vue Secure Token plugin');
        this.context.commit('SET_SERVER_ERROR');
    }

    @Action
    public setUnauthorized() {
        console.log('Setting unauthorized from Vue Secure Token plugin');
        this.context.commit('SET_UNAUTHORIZED');
    }

    @Action
    public setApi(args: { spContext: WebPartContext, appBasePath: string }) {
        this.context.commit('SET_SPCONTEXT', args.spContext);
        this.context.commit('SET_API_BASE_URL', args.appBasePath);
        this.context.dispatch('fetchJwtToken');
    }

    @Action({ rawError: true })
    public async fetchJwtToken() {
        try {
            const tokenProvider = await this.sharepointContext.aadTokenProviderFactory.getTokenProvider();
            const token = await tokenProvider.getToken(`https://${window.location.hostname}`);
            this.context.commit('SET_TOKEN', token);
            return;
        }
        catch (err) {
            return Promise.reject(err);
        }
    }

}
export default SecureToken;
